![](https://img.shields.io/github/actions/workflow/status/BenPortner/pydbk/install-lint-test.yml?label=tests) ![](https://img.shields.io/github/actions/workflow/status/BenPortner/pydbk/release-pypi.yml?label=release) ![](https://img.shields.io/github/license/BenPortner/pydbk) ![](https://img.shields.io/pypi/pyversions/pydbk)

# Pydbk: A Python tool to extract .dbk archives

Pydbk consists of a python module `pydbk.py` and a command line tool `pydbk_cli.py`.

## Usage

For help type:

```
python pydbk_cli.py -h
```